Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(264)

Unified Diff: net/log/write_to_file_net_log_observer.h

Issue 2603523002: Move net-export thread-hopping code into NetLogFileWriter and add IO polled data. (Closed)
Patch Set: Various refactors to make code cleaner Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: net/log/write_to_file_net_log_observer.h
diff --git a/net/log/write_to_file_net_log_observer.h b/net/log/write_to_file_net_log_observer.h
index 2ef4189f2ff99ad60033a49fb1b88bfeb3fb791e..87671a2e441b657c19977ab5368a4611f9d09b85 100644
--- a/net/log/write_to_file_net_log_observer.h
+++ b/net/log/write_to_file_net_log_observer.h
@@ -53,10 +53,9 @@ class NET_EXPORT WriteToFileNetLogObserver : public NetLog::ThreadSafeObserver {
// Stops observing net_log(). Must already be watching. Must be called
// before destruction of the WriteToFileNetLogObserver and the NetLog.
//
- // |url_request_context| is an optional argument used to added additional
- // network stack state to the log. If the context is non-NULL, this must be
- // called on the context's thread.
- void StopObserving(URLRequestContext* url_request_context);
+ // |polled_data| is an optional argument used to added additional
+ // network stack state to the log.
+ void StopObserving(base::Value* polled_data);
// net::NetLog::ThreadSafeObserver implementation:
void OnAddEntry(const NetLogEntry& entry) override;

Powered by Google App Engine
This is Rietveld 408576698